package com.fs.survey.mapper;

import com.fs.survey.domain.SurveyFieldConfig;
import java.util.List;

/**
 * 问卷字段配置Mapper接口
 *
 */
public interface SurveyFieldConfigMapper {
    /**
     * 查询问卷字段配置
     *
     * @param id 问卷字段配置主键
     * @return 问卷字段配置
     */
    public SurveyFieldConfig selectSurveyFieldConfigById(Long id);

    /**
     * 查询问卷字段配置列表
     *
     * @param surveyFieldConfig 问卷字段配置
     * @return 问卷字段配置集合
     */
    public List<SurveyFieldConfig> selectSurveyFieldConfigList(SurveyFieldConfig surveyFieldConfig);

    /**
     * 根据版本ID查询字段配置列表
     *
     * @param versionId 版本ID
     * @return 字段配置集合
     */
    public List<SurveyFieldConfig> selectFieldConfigByVersionId(Long versionId);

    /**
     * 新增问卷字段配置
     *
     * @param surveyFieldConfig 问卷字段配置
     * @return 结果
     */
    public int insertSurveyFieldConfig(SurveyFieldConfig surveyFieldConfig);

    /**
     * 修改问卷字段配置
     *
     * @param surveyFieldConfig 问卷字段配置
     * @return 结果
     */
    public int updateSurveyFieldConfig(SurveyFieldConfig surveyFieldConfig);

    /**
     * 删除问卷字段配置
     *
     * @param id 问卷字段配置主键
     * @return 结果
     */
    public int deleteSurveyFieldConfigById(Long id);

    /**
     * 批量删除问卷字段配置
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSurveyFieldConfigByIds(Long[] ids);

    /**
     * 根据版本ID删除字段配置
     *
     * @param versionId 版本ID
     * @return 结果
     */
    public int deleteSurveyFieldConfigByVersionId(Long versionId);
}
